package services

type BaseArgs struct {
	IMEI string
}

type EmptyResult struct{}

type GPSInfoReply struct {
	Lat float64
	Lng float64
}

type SetDTUModeArgs struct {
	BaseArgs
	Mode    int // 模式
	Channel int // 通道
}

type DTUModeReply struct {
	Channel1 int // 通道1
	Channel2 int // 通道2
	Channel3 int // 通道3
	Channel4 int // 通道4
}

type ServerAddrArgs struct {
	BaseArgs
	Channel  int    // 通道
	LinkType string // 连接类型
	Ip       string // Ip或域名
	Port     int    // 端口
}

type ServerAddrReply struct {
	Addrs []*Addr
}

type Addr struct {
	Channel  int    // 通道
	LinkType string // 连接类型
	Addr     string // IP或域名
	Port     int    // 端口
}

type UARTArgs struct {
	BaseArgs
	Rate int // 波特率
	DBit int // 数据位
	CBit int // 校验位
	SBit int // 停止位
}

type UARTReply struct {
	Rate int // 波特率
	DBit int // 数据位
	CBit int // 校验位
	SBit int // 停止位
}

type DTUIDArgs struct {
	BaseArgs
	Mode    int
	IdType  int
	Format  int
	Content string
	Channel int
}

type DTUIDReply struct {
	DTUIDs []*DTUID
}

type DTUID struct {
	Mode    int
	IdType  int
	Format  int
	Content string
	Channel int
}

type KeepAliveArgs struct {
	BaseArgs
	Duration int    // 心跳间隔
	Format   int    // 数据格式
	Content  string // 心跳包内容
	Channel  int    // 通道
}

type KeepAliveReply struct {
	Channels []*KeepAlive
}

type KeepAlive struct {
	Duration int    // 心跳间隔
	Format   int    // 数据格式
	Content  string // 心跳包内容
	Channel  int    // 通道
}

type PollArgs struct {
	BaseArgs
	Sw       int // 是否使能
	Duration int // 轮询间隔
	Format   int // 内容格式
}

type PollReply struct {
	Sw       int // 是否使能
	Duration int // 轮询间隔
	Format   int // 内容格式
}

type PollStrArgs struct {
	BaseArgs
	Index   int    // 轮询字串号，取值范围 1-10
	Sw      int    // 字串轮询使能
	Crc     int    // CRC使能
	Content string // 轮询内容
}

type PollStrReply struct {
	Strings []*PollStr
}

type PollStr struct {
	Sw      int    // 字串轮询使能
	Crc     int    // CRC使能
	Content string // 轮询内容
}
